
/*

cellwriter -- a character recognition input method
Copyright (C) 2007 Michael Levin <risujin@risujin.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#include "config.h"
#include "common.h"

/* options.c */
void options_dialog_open(void);

/* window.c */
extern GtkWidget *window;

void window_toggle(void);

/*
        Status icon with GtkStatusIcon
*/

static GtkWidget *status_menu, *status_menu_show = NULL;
static GtkStatusIcon *status_icon = NULL;

int status_icon_embedded(void)
{
        /* FIXME Doesn't actually test if the icon is embedded because this
                 function is called before the icon has had a chance to
                 embed! */
        return status_icon != NULL;
}

static void status_menu_popup(GtkStatusIcon *status, guint button,
                              guint activate_time)
{
        GtkWidget *widget, *image;

        if (status_menu)
                gtk_widget_destroy(status_menu);
        status_menu = gtk_menu_new();

        /* Menu -> Show/Hide */
        if (GTK_WIDGET_VISIBLE(window))
                status_menu_show = gtk_menu_item_new_with_label("Hide");
        else
                status_menu_show = gtk_menu_item_new_with_label("Show");
        g_signal_connect(G_OBJECT(status_menu_show), "activate",
                         G_CALLBACK(window_toggle), NULL);
        gtk_menu_attach(GTK_MENU(status_menu), status_menu_show, 0, 1, 0, 1);

        /* Menu -> Setup */
        widget = gtk_image_menu_item_new_with_label("Setup");
        image = gtk_image_new();
        gtk_image_set_from_stock(GTK_IMAGE(image), GTK_STOCK_PREFERENCES,
                                 GTK_ICON_SIZE_MENU);
        gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(widget), image);
        g_signal_connect(G_OBJECT(widget), "activate",
                         G_CALLBACK(options_dialog_open), 0);
        gtk_menu_attach(GTK_MENU(status_menu), widget, 0, 1, 1, 2);

        /* Menu -> Separator */
        widget = gtk_separator_menu_item_new();
        gtk_menu_attach(GTK_MENU(status_menu), widget, 0, 1, 2, 3);

        /* Menu -> Close */
        widget = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, NULL);
        g_signal_connect(G_OBJECT(widget), "activate",
                         G_CALLBACK(gtk_main_quit), NULL);
        gtk_menu_attach(GTK_MENU(status_menu), widget, 0, 1, 3, 4);

        /* Popup the menu */
        gtk_widget_show_all(status_menu);
        gtk_menu_popup(GTK_MENU(status_menu), NULL, NULL,
                       gtk_status_icon_position_menu, status_icon,
                       button, activate_time);
}

void status_icon_create(void)
/* Create the system tray icon and associated menu */
{
        char *icon_path;
        GError *error = NULL;
        GdkPixbuf *pixbuf;

        /* Create the system tray icon */
        icon_path = g_build_filename(DATADIR, ICON_PATH PACKAGE ".svg", NULL);
        if (!(pixbuf = gdk_pixbuf_new_from_file(icon_path, &error))) {
                status_icon = NULL;
                g_warning(error->message);
                g_warning("Failed to load status icon '%s'", icon_path);
                return;
        }
        status_icon = gtk_status_icon_new_from_pixbuf(pixbuf);
	g_object_unref(pixbuf);
        g_signal_connect(G_OBJECT(status_icon), "activate",
                         G_CALLBACK(window_toggle), NULL);
        g_signal_connect(G_OBJECT(status_icon), "popup-menu",
                         G_CALLBACK(status_menu_popup), NULL);
        gtk_status_icon_set_visible(status_icon, TRUE);
}

